Storing Data
============

.. contents:: :local:


In science, people want to store results, either intermediate ones to have
a "checkpoint" in a potentially huge analysis chain or of course final results which are only
used for high level analysis, data visualisation and interpretation.
HDF5 is a dataformat which is open source, popular among (data) scientists
and flexible enough to store all kinds of data.



Work in progress...

